==> openshift-model-6.4.1-sources.jar: io/fabric8/openshift/api/model/OAuthAuthorizeTokenListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthAuthorizeTokenListFluent<A extends OAuthAuthorizeTokenListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,OAuthAuthorizeToken item);
  public A setToItems(Integer index,OAuthAuthorizeToken item);
  public A addToItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public A addAllToItems(Collection<OAuthAuthorizeToken> items);
  public A removeFromItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public A removeAllFromItems(Collection<OAuthAuthorizeToken> items);
  public A removeMatchingFromItems(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OAuthAuthorizeToken> getItems();
  public List<OAuthAuthorizeToken> buildItems();
  public OAuthAuthorizeToken buildItem(Integer index);
  public OAuthAuthorizeToken buildFirstItem();
  public OAuthAuthorizeToken buildLastItem();
  public OAuthAuthorizeToken buildMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public A withItems(List<OAuthAuthorizeToken> items);
  public A withItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public Boolean hasItems();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> addNewItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> addNewItemLike(OAuthAuthorizeToken item);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> setNewItemLike(Integer index,OAuthAuthorizeToken item);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editItem(Integer index);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editFirstItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editLastItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,OAuthAuthorizeTokenFluent<OAuthAuthorizeTokenListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/OAuthAuthorizeTokenListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthAuthorizeTokenListFluent<A extends OAuthAuthorizeTokenListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,OAuthAuthorizeToken item);
  public A setToItems(int index,OAuthAuthorizeToken item);
  public A addToItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public A addAllToItems(Collection<OAuthAuthorizeToken> items);
  public A removeFromItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public A removeAllFromItems(Collection<OAuthAuthorizeToken> items);
  public A removeMatchingFromItems(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<OAuthAuthorizeToken> getItems();
  public List<OAuthAuthorizeToken> buildItems();
  public OAuthAuthorizeToken buildItem(int index);
  public OAuthAuthorizeToken buildFirstItem();
  public OAuthAuthorizeToken buildLastItem();
  public OAuthAuthorizeToken buildMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public A withItems(List<OAuthAuthorizeToken> items);
  public A withItems(io.fabric8.openshift.api.model.OAuthAuthorizeToken... items);
  public Boolean hasItems();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> addNewItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> addNewItemLike(OAuthAuthorizeToken item);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> setNewItemLike(int index,OAuthAuthorizeToken item);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editItem(int index);
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editFirstItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editLastItem();
  public OAuthAuthorizeTokenListFluent.ItemsNested<A> editMatchingItem(Predicate<OAuthAuthorizeTokenBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,OAuthAuthorizeTokenFluent<OAuthAuthorizeTokenListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
